const { Client, GatewayIntentBits } = require('discord.js');
const fs = require('fs');
const { REST } = require('@discordjs/rest');
const { Routes } = require('discord-api-types/v9');

const config = require('./config.json');

const client = new Client({
  intents: [
    GatewayIntentBits.Guilds,
    GatewayIntentBits.GuildMessages,
    GatewayIntentBits.GuildMembers,
    GatewayIntentBits.GuildVoiceStates, 
  ],
});

client.commands = new Map();

const rest = new REST({ version: '9' }).setToken(config.token);

// Wczytaj wszystkie pliki z folderu events
const eventFiles = fs.readdirSync('./events').filter(file => file.endsWith('.js'));

for (const file of eventFiles) {
  const event = require(`./events/${file}`);
  if (event.once) {
    client.once(event.name, (...args) => event.execute(...args, client));
  } else {
    client.on(event.name, (...args) => event.execute(...args, client));
  }
}

// Wczytaj wszystkie pliki z folderu commands
const commandFiles = fs.readdirSync('./commands').filter(file => file.endsWith('.js'));

for (const file of commandFiles) {
  const command = require(`./commands/${file}`);
  client.commands.set(command.data.name, command); // Dodanie komendy do mapy
}

// Odświeżenie poleceń aplikacji
(async () => {
  try {
    console.log('Rozpoczęto odświeżanie poleceń aplikacji (/).');

    await rest.put(
      Routes.applicationGuildCommands(config.clientId, config.guildId),
      { body: Array.from(client.commands.values()).map(command => command.data.toJSON()) },
    );

    console.log('Pomyślnie załadowano ponownie polecenia aplikacji (/).');
  } catch (error) {
    console.error(error);
  }
})();

client.on('ready', () => {
  console.log(`Zalogowany jako ${client.user.tag}`);
});

client.on('interactionCreate', async (interaction) => {
  if (!interaction.isCommand()) return;

  const { commandName } = interaction;

  if (client.commands.has(commandName)) {
    try {
      await client.commands.get(commandName).execute(interaction);
    } catch (error) {
      console.error(error);
      await interaction.reply('Wystąpił błąd podczas wykonywania komendy.');
    }
  }
});

client.login(config.token);
